@@ -42,9 +42,13 @@ class Channel(base.AMQPChannel):
 
     def __init__(self, channel_id, events,
                  exception_queue, read_queue, write_queue,
-                 maximum_frame_size, write_trigger):
+                 maximum_frame_size, write_trigger, blocking_read=False):
         """Create a new instance of the Channel class
 
+        To improve performance, pass blocking_read to True. Note that doing
+        so prevents KeyboardInterrupt/CTRL-C from exiting the Python
+        interpreter.
+
         :param int channel_id: The channel # to use for this instance
         :param events rabbitpy.Events: Event management object
         :param queue.Queue exception_queue: Exception queue
@@ -52,9 +56,11 @@ class Channel(base.AMQPChannel):
         :param queue.Queue write_queue: Queue to write pending AMQP objs to
         :param int maximum_frame_size: The max frame size for msg bodies
         :param socket write_trigger: Write to this socket to break IO waiting
+        :param bool blocking: Use blocking Queue.get to improve performance
 
         """
-        super(Channel, self).__init__(exception_queue, write_trigger)
+        super(Channel, self).__init__(exception_queue, write_trigger,
+                                      blocking_read)
         self._channel_id = channel_id
         self._consumers = []
         self._events = events
@@ -123,20 +129,6 @@ class Channel(base.AMQPChannel):
 
         super(Channel, self).close()
 
-    def _get_from_read_queue(self):
-        """Fetch a frame from the read queue and return it, otherwise return
-        None
-
-        :rtype: pamqp.specification.Frame
-
-        """
-        try:
-            frame_value = self._read_queue.get(False)
-            self._read_queue.task_done()
-        except queue.Empty:
-            return None
-        return frame_value
-
     def enable_publisher_confirms(self):
         """Turn on Publisher Confirms. If confirms are turned on, the
         Message.publish command will return a bool indicating if a message has
@@ -297,6 +289,20 @@ class Channel(base.AMQPChannel):
         msg.name = method_frame.name
         return msg
 
+    def _get_from_read_queue(self):
+        """Fetch a frame from the read queue and return it, otherwise return
+        None
+
+        :rtype: pamqp.specification.Frame
+
+        """
+        try:
+            frame_value = self._read_queue.get(False)
+            self._read_queue.task_done()
+        except queue.Empty:
+            return None
+        return frame_value
+
     def _get_message(self):
         """Try and get a delivered message from the connection's message stack.
 
